# REST APIs Overview
Get an overview of available REST APIs and learn when to use each API.
You can browse available REST APIs and try out requests in the [OpenAPI Explorer![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%23%2F "https://app.leanix.net/openapi-explorer/#/").
REST API | Usage | Related Information
---|---|---
Apptio Connector API | Configure and run your Apptio integration. |  [Apptio Integration](https://help.sap.com/docs/leanix/ea/apptio-integration?locale=en-US&state=PRODUCTION&version=CLOUD "With the out-of-the-box Apptio integration in SAP LeanIX, you will get a holistic overview of your business, IT and finances.")
Automations API | Manage your automation templates and retrieve information about instances and quota. |  [Automations](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD "Configure no-code automations to streamline your workflows.")
Discovery SaaS API | Manage SaaS discovery integrations and access discovered data. |  [SaaS Discovery](https://help.sap.com/docs/leanix/ea/saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SaaS discovery identifies your organization's SaaS applications by integrating with SSO, SASE, and CASB solutions. It then updates and enriches fact sheets using the reference catalog.")
Import Export API | Interact with Inventory data through Excel files and the standardized OData capability. |
  * [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.")
  * [Exporting Fact Sheet Data as Excel File](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s export feature allows you to export fact sheet data as an Excel file for bulk updates, easy data manipulation, and offline analysis. The exported file also serves as a template for importing data back into SAP LeanIX.")
  * [OData Integration](https://help.sap.com/docs/leanix/ea/odata-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Export fact sheet data into business intelligence tools through OData endpoints.")


Integration API | Configure and run your custom integrations. |  [Integration REST API](https://help.sap.com/docs/leanix/ea/integration-rest-api?locale=en-US&state=PRODUCTION&version=CLOUD "How to connect to the Integration API from an external system.")
Integration Collibra API | Configure and run your Collibra integration. |  [Collibra Integration](https://help.sap.com/docs/leanix/ea/collibra-integration?locale=en-US&state=PRODUCTION&version=CLOUD "The integration between SAP LeanIX and Collibra enhances data governance by aligning enterprise and data architecture. With increased transparency and accessibility, stakeholders can make informed decisions on data management and compliance.")
Integration ServiceNow API | Configure and run your ServiceNow integration. |  [ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Fundamentals of the SAP LeanIX integration with ServiceNow \(CMDB\).")
Integration Signavio API | Configure and run your SAP Signavio integration. |  [SAP Signavio Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration?locale=en-US&state=PRODUCTION&version=CLOUD "The integration between SAP LeanIX and SAP Signavio enables seamless data synchronization, ensuring both systems have consistent and up-to-date information about business processes and IT systems. Learn how to set up the integration and how to map and sync data between SAP LeanIX and SAP Signavio.")
MTM API | Automate user management tasks for your workspaces. |
  * [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to authenticate to SAP LeanIX services.")
  * [Managing Users](https://help.sap.com/docs/leanix/ea/managing-users?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to manage user access and roles with and without single sign-on \(SSO\).")


Metrics API | Track your own metrics and set up KPIs based on inventory filters. |  [Metrics](https://help.sap.com/docs/leanix/ea/metrics?locale=en-US&state=PRODUCTION&version=CLOUD "Metrics help you to display KPIs and their development over time in the context of the right Fact Sheet.")
Navigation API | Manage collections of reports and diagrams. |  [Collections](https://help.sap.com/docs/leanix/ea/collections?locale=en-US&state=PRODUCTION&version=CLOUD "Use collections to arrange dashboards, reports, and diagrams into custom groups.")
Notifications API | Manage your notification settings. |  [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center?locale=en-US&state=PRODUCTION&version=CLOUD "Configure notification settings for your workspace.")
Pathfinder API | Search for and manage the lifecycle of inventory fact sheets, such as create or modify your fact sheets. We recommend that you use our GraphQL API to work with fact sheets. Manage bookmarks programmatically. |
  * [GraphQL API](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD "Get started with the SAP LeanIX GraphQL API.")
  * [Bookmarks](https://help.sap.com/docs/leanix/ea/bookmarks?locale=en-US&state=PRODUCTION&version=CLOUD "Manage saved searches, reports, diagrams, and dashboards through the Pathfinder REST API.")


Recon API | Get recommendations on potentially related fact sheets for a specific fact sheet and its description. |
Reference Data API | Maintain links between your fact sheets and our reference catalog. |  [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.")
Self-Built Software Discovery API | Manage microservices and their associated Software Bill of Materials (SBOMs). | [Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance enables you to automate the discovery of your self-built software by integrating this process into your developer toolchain.")
Storage API | Manage and retrieve file resources for your workspace. |
Survey API | Manage your surveys, survey runs, and survey submissions. | [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.")
Synclog API | Get and update synchronization logs of your out-of-the-box or custom integrations. |  [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD "Use synchronization logs to track the state of your integrations.")
To-do API | Manage your to-dos and to-do assignees. | [To-Dos (Administration)](https://help.sap.com/docs/leanix/ea/to-dos-administration?locale=en-US&state=PRODUCTION&version=CLOUD "As an admin, learn how to create approval to-dos and manage all the to-do items in the administration area.")
Transformations API | Manage transformations and impacts. |
  * [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.")
  * [Impacts](https://help.sap.com/docs/leanix/ea/impacts?locale=en-US&state=PRODUCTION&version=CLOUD "Impacts detail the changes at attribute and relation levels. Learn how to manage these Impacts in SAP LeanIX Architecture and Road Map Planning.")


Webhooks API | Subscribe to domain events within SAP LeanIX. |  [Webhooks](https://help.sap.com/docs/leanix/ea/webhooks?locale=en-US&state=PRODUCTION&version=CLOUD "Listen to events in SAP LeanIX using webhooks.")


YesNo
Send
